@@ -336,7 +336,7 @@ class Exploit < Msf::Module
   # exploit module.  It will also pre-generate the desired payload, though
   # exploits can re-generate the payload if necessary.
   #
-  # This method is designed to be overriden by exploit modules.
+  # This method is designed to be overridden by exploit modules.
   #
   def exploit
   end
@@ -1475,7 +1475,7 @@ class Exploit < Msf::Module
       :run_id      => self.datastore['RUN_ID']
     }
 
-    if self.datastore['RHOST'] and self.options['RHOST']
+    if self.datastore['RHOST'] && (self.options['RHOST'] || self.options['RHOSTS'])
       info[:host] = self.datastore['RHOST']
     end
 
