@@ -20,23 +20,6 @@ module Msf
         settings['queries']
       end
 
-      def perform_ldap_query(ldap, filter, attributes, base, schema_dn, scope: nil)
-        results = []
-        perform_ldap_query_streaming(ldap, filter, attributes, base, schema_dn, scope: scope) do |result|
-          results << result
-        end
-
-        query_result_table = ldap.get_operation_result.table
-        validate_result!(query_result_table, filter)
-
-        if results.nil? || results.empty?
-          print_error("No results found for #{filter}.")
-          return nil
-        end
-
-        results
-      end
-
       def perform_ldap_query_streaming(ldap, filter, attributes, base, schema_dn, scope: nil)
         if attributes.nil? || schema_dn.nil?
           attribute_properties = {}
@@ -284,6 +267,14 @@ module Msf
             end
             normalized_attribute[0] = time_string
           when 66 # String (Nt Security Descriptor)
+            if attribute_property[:attributesyntax] == '2.5.5.15'
+              begin
+                sd = Rex::Proto::MsDtyp::MsDtypSecurityDescriptor.read(entry[attribute_name][0])
+                normalized_attribute[0] = sd.to_sddl_text(domain_sid: nil)
+              rescue StandardError => e
+                elog('failed to parse a binary security descriptor to SDDL', error: e)
+              end
+            end
           when 127 # Object
           else
             print_error("Unknown oMSyntax entry: #{attribute_property[:omsyntax]}")
