@@ -42,8 +42,7 @@ class MetasploitModule < Msf::Auxiliary
   def smb_delete_files
     if session
       print_status("Using existing session #{session.sid}")
-      client = session.client
-      self.simple = ::Rex::Proto::SMB::SimpleClient.new(client.dispatcher.tcp_socket, client: client)
+      self.simple = session.simple_client
     else
       vprint_status("Connecting to the server...")
       connect()
