@@ -18,6 +18,9 @@ class MetasploitModule < Msf::Auxiliary
 
     register_advanced_options([
       OptString.new('ExcludePathPatterns', [false, 'Newline-separated list of path patterns to ignore (\'*\' is a wildcard)']),
+      OptBool.new('HttpTrace', [false, 'Show the raw HTTP requests and responses', false]),
+      OptBool.new('HttpTraceHeadersOnly', [false, 'Show HTTP headers only in HttpTrace', false]),
+      OptString.new('HttpTraceColors', [false, 'HTTP request and response colors for HttpTrace (unset to disable)', 'red/blu']),
     ])
     @for_each_page_blocks = []
   end
@@ -60,7 +63,7 @@ class MetasploitModule < Msf::Auxiliary
   #
   # Data we will report:
   # - The path of any URL found by the crawler (web.uri, :path => page.path)
-  # - The occurence of any form (web.form :path, :type (get|post|path_info), :params)
+  # - The occurrence of any form (web.form :path, :type (get|post|path_info), :params)
   #
   def crawler_process_page(t, page, cnt)
     return if page.nil? # Skip over pages that don't contain any info aka page is nil. We can't process these types of pages since there is no data to process.
