@@ -13,6 +13,7 @@ class MetasploitModule < Msf::Auxiliary
   include Msf::Auxiliary::Scanner
   include Msf::Sessions::CreateSessionOptions
   include Msf::Auxiliary::CommandShell
+  include Msf::Auxiliary::ReportSummary
 
   def initialize(info = {})
     super(update_info(info,
@@ -39,11 +40,10 @@ class MetasploitModule < Msf::Auxiliary
         OptBool.new('CreateSession', [false, 'Create a new session for every successful login', false])
       ])
 
-    options_to_deregister = %w[PASSWORD_SPRAY]
     if framework.features.enabled?(Msf::FeatureManager::MYSQL_SESSION_TYPE)
       add_info('New in Metasploit 6.4 - The %grnCreateSession%clr option within this module can open an interactive session')
     else
-      options_to_deregister << 'CreateSession'
+      options_to_deregister = %w[CreateSession]
     end
     deregister_options(*options_to_deregister)
   end
@@ -66,7 +66,9 @@ class MetasploitModule < Msf::Auxiliary
     logins = results.flat_map { |_k, v| v[:successful_logins] }
     sessions = results.flat_map { |_k, v| v[:successful_sessions] }
     print_status("Bruteforce completed, #{logins.size} #{logins.size == 1 ? 'credential was' : 'credentials were'} successful.")
-    if datastore['CreateSession']
+    return results unless framework.features.enabled?(Msf::FeatureManager::MYSQL_SESSION_TYPE)
+
+    if create_session?
       print_status("#{sessions.size} MySQL #{sessions.size == 1 ? 'session was' : 'sessions were'} opened successfully.")
     else
       print_status('You can open an MySQL session with these credentials and %grnCreateSession%clr set to true')
@@ -83,9 +85,7 @@ class MetasploitModule < Msf::Auxiliary
         )
 
         scanner = Metasploit::Framework::LoginScanner::MySQL.new(
-            host: ip,
-            port: rport,
-            proxies: datastore['Proxies'],
+          configure_login_scanner(
             cred_details: cred_collection,
             stop_on_success: datastore['STOP_ON_SUCCESS'],
             bruteforce_speed: datastore['BRUTEFORCE_SPEED'],
@@ -101,6 +101,7 @@ class MetasploitModule < Msf::Auxiliary
             ssl_cipher: datastore['SSLCipher'],
             local_port: datastore['CPORT'],
             local_host: datastore['CHOST']
+          )
         )
 
         successful_logins = []
