@@ -28,7 +28,7 @@ class MetasploitModule < Msf::Exploit::Remote
         'References' => [
           [ 'OSVDB', '88751' ],
           [ 'BID', '57058' ],
-          [ 'URL', 'http://itsecuritysolutions.org/2012-12-31-eXtplorer-v2.1-authentication-bypass-vulnerability' ],
+          [ 'URL', 'http://web.archive.org/web/20230128023508/https://itsecuritysolutions.org/2012-12-31-eXtplorer-v2.1-authentication-bypass-vulnerability/' ],
           [ 'URL', 'http://extplorer.net/issues/105' ]
         ],
         'Payload' => {
