@@ -13,7 +13,7 @@ class MetasploitModule < Msf::Post
         info,
         'Name' => 'Multi Recon Local Exploit Suggester',
         'Description' => %q{
-          This module suggests local meterpreter exploits that can be used.
+          This module suggests local Metasploit exploits that can be used.
 
           The exploits are suggested based on the architecture and platform
           that the user has a shell opened as well as the available exploits
@@ -26,22 +26,25 @@ class MetasploitModule < Msf::Post
         'License' => MSF_LICENSE,
         'Author' => [ 'sinn3r', 'Mo' ],
         'Platform' => all_platforms,
-        'SessionTypes' => [ 'meterpreter', 'shell' ]
+        'SessionTypes' => [ 'meterpreter', 'shell' ],
+        'Notes' => {
+          'Stability' => [SERVICE_RESOURCE_LOSS],
+          'SideEffects' => [IOC_IN_LOGS, ARTIFACTS_ON_DISK, CONFIG_CHANGES],
+          'Reliability' => []
+        }
       )
     )
-    register_options [
+    register_options([
       Msf::OptInt.new('SESSION', [ true, 'The session to run this module on' ]),
       Msf::OptBool.new('SHOWDESCRIPTION', [true, 'Displays a detailed description for the available exploits', false])
-    ]
+    ])
 
-    register_advanced_options(
-      [
-        Msf::OptBool.new('ValidateArch', [true, 'Validate architecture', true]),
-        Msf::OptBool.new('ValidatePlatform', [true, 'Validate platform', true]),
-        Msf::OptBool.new('ValidateMeterpreterCommands', [true, 'Validate Meterpreter commands', false]),
-        Msf::OptString.new('Colors', [false, 'Valid, Invalid and Ignored colors for module checks (unset to disable)', 'grn/red/blu'])
-      ]
-    )
+    register_advanced_options([
+      Msf::OptBool.new('ValidateArch', [true, 'Validate architecture', true]),
+      Msf::OptBool.new('ValidatePlatform', [true, 'Validate platform', true]),
+      Msf::OptBool.new('ValidateMeterpreterCommands', [true, 'Validate Meterpreter commands', false]),
+      Msf::OptString.new('Colors', [false, 'Valid, Invalid and Ignored colors for module checks (unset to disable)', 'grn/red/blu'])
+    ])
   end
 
   def all_platforms
@@ -110,8 +113,9 @@ class MetasploitModule < Msf::Post
   end
 
   def set_module_options(mod)
+    ignore_list = ['ACTION', 'TARGET'].freeze
     datastore.each_pair do |k, v|
-      mod.datastore[k] = v
+      mod.datastore[k] = v unless ignore_list.include?(k.upcase)
     end
     if !mod.datastore['SESSION'] && session.present?
       mod.datastore['SESSION'] = session.sid
