@@ -14,13 +14,18 @@ class MetasploitModule < Msf::Post
         info,
         'Name' => 'Windows Gather ARP Scanner',
         'Description' => %q{
-          This Module will perform an ARP scan for a given IP range through a
-          Meterpreter Session.
+          This module will perform an ARP scan for a given IP range through a
+          Meterpreter session.
         },
         'License' => MSF_LICENSE,
         'Author' => [ 'Carlos Perez <carlos_perez[at]darkoperator.com>'],
         'Platform' => [ 'win' ],
         'SessionTypes' => [ 'meterpreter'],
+        'Notes' => {
+          'Stability' => [CRASH_SAFE],
+          'SideEffects' => [],
+          'Reliability' => []
+        },
         'Compat' => {
           'Meterpreter' => {
             'Commands' => %w[
@@ -34,14 +39,13 @@ class MetasploitModule < Msf::Post
       [
         OptString.new('RHOSTS', [true, 'The target address range or CIDR identifier', nil]),
         OptInt.new('THREADS', [false, 'The number of concurrent threads', 10])
-
       ]
     )
   end
 
-  # Run Method for when run command is issued
   def run
-    print_status("Running module against #{sysinfo['Computer']}")
+    hostname = sysinfo.nil? ? cmd_exec('hostname') : sysinfo['Computer']
+    print_status("Running module against #{hostname} (#{session.session_host})")
     arp_scan(datastore['RHOSTS'], datastore['THREADS'])
   end
 
@@ -50,39 +54,40 @@ class MetasploitModule < Msf::Post
     ws = client.railgun.ws2_32
     iphlp = client.railgun.iphlpapi
     a = []
-    iplst, found = [], ""
+    iplst = []
+    found = ''
     ipadd = Rex::Socket::RangeWalker.new(cidr)
     numip = ipadd.num_ips
     while (iplst.length < numip)
       ipa = ipadd.next_ip
-      if (not ipa)
+      if !ipa
         break
       end
 
       iplst << ipa
     end
 
-    while (not iplst.nil? and not iplst.empty?)
+    while !iplst.nil? && !iplst.empty?
       a = []
       1.upto(threads) do
-        a << framework.threads.spawn("Module(#{self.refname})", false, iplst.shift) do |ip_text|
+        a << framework.threads.spawn("Module(#{refname})", false, iplst.shift) do |ip_text|
           next if ip_text.nil?
 
           h = ws.inet_addr(ip_text)
-          ip = h["return"]
+          ip = h['return']
           h = iphlp.SendARP(ip, 0, 6, 6)
-          if h["return"] == client.railgun.const("NO_ERROR")
-            mac_text = h["pMacAddr"].unpack('C*').map { |e| "%02x" % e }.join(':')
-            company = OUI_LIST::lookup_oui_company_name(mac_text)
+          if h['return'] == client.railgun.const('NO_ERROR')
+            mac_text = h['pMacAddr'].unpack('C*').map { |e| '%02x' % e }.join(':')
+            company = OUI_LIST.lookup_oui_company_name(mac_text)
             print_good("\tIP: #{ip_text} MAC #{mac_text} (#{company})")
-            report_host(:host => ip_text, :mac => mac_text)
+            report_host(host: ip_text, mac: mac_text)
             next if company.nil?
 
-            report_note(:host => ip_text, :type => "mac_oui", :data => company)
+            report_note(host: ip_text, type: 'mac_oui', data: company)
           end
         end
       end
-      a.map { |x| x.join }
+      a.map(&:join)
     end
     return found
   end
